---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior (include a minimal code snippet if possible)

**Expected behavior**
A clear and concise description of what you expected to happen.

**Actual behavior**
A description of what actually happened.

**`clinlp` version**
The `clinlp` version. You can find it by typing `pip show clinlp` in a terminal.

**Python version**
The Python version. You can find it by typing `python --version` in a terminal.

**Any other relevant information**
Add any other context about the problem here.
